Class: Characterize::RelationCollection
- Inherits:
-
Collection
- Object
- Collection
- Characterize::RelationCollection
- Extended by:
- Direction
- Defined in:
- lib/characterize/relation_collection.rb
Instance Attribute Summary
Attributes inherited from Collection
#behaviors, #casted_enum, #collection
Instance Method Summary collapse
- #limit ⇒ Object
-
#not ⇒ Object
Defined before safe_command/query so these names are excluded from the auto-generated delegators (see Collection.safe_command) rather than redefining them.
- #offset ⇒ Object
Methods inherited from Collection
for, #initialize, #inspect, register, registry, safe_command
Constructor Details
This class inherits a constructor from Characterize::Collection
Instance Method Details
#limit ⇒ Object
18 19 20 21 |
# File 'lib/characterize/relation_collection.rb', line 18 def limit(...) reset_collection collection.limit(...) self end |
#not ⇒ Object
Defined before safe_command/query so these names are excluded from the auto-generated delegators (see Collection.safe_command) rather than redefining them.
13 14 15 16 |
# File 'lib/characterize/relation_collection.rb', line 13 def not(...) reset_collection collection.where.not(...) self end |
#offset ⇒ Object
23 24 25 26 |
# File 'lib/characterize/relation_collection.rb', line 23 def offset(...) reset_collection collection.offset(...) self end |